@@ -4,6 +4,7 @@
 from __future__ import absolute_import, division, print_function
 
 import itertools
+import os
 import warnings
 
 import mando
@@ -59,8 +60,6 @@ MARKER_LIST = [
     "_",
 ]
 
-COLOR_LIST = ["b", "g", "r", "c", "m", "y", "k"]
-
 LINE_LIST = ["-", "--", "-.", ":", "solid", "dashed", "dashdot", "dotted"]
 
 HATCH_LIST = ["/", "\\", "|", "-", "+", "x", "o", "O", ".", "*"]
@@ -189,6 +188,17 @@ def plot_cli(
     source_units=None,
     target_units=None,
     lag_plot_lag=1,
+    plot_styles="bright",
+    hlines_y=None,
+    hlines_xmin=None,
+    hlines_xmax=None,
+    hlines_colors=None,
+    hlines_linestyles="-",
+    vlines_x=None,
+    vlines_ymin=None,
+    vlines_ymax=None,
+    vlines_colors=None,
+    vlines_linestyles="-",
 ):
     r"""Plot data.
 
@@ -354,12 +364,18 @@ def plot_cli(
     colors
         [optional, default is 'auto']
 
-        The default 'auto' will cycle through matplotlib colors.  Otherwise at
-        command line supply a comma separated matplotlib color codes, or
-        within Python a list of color code strings.
+        The default 'auto' will cycle through matplotlib colors in the chosen
+        style.
 
-        Separated 'colors', 'linestyles', and 'markerstyles' instead of using
-        the 'style' keyword.
+        At the command line supply a comma separated matplotlib
+        color codes, or within Python a list of color code strings.
+
+        Can identify colors in four different ways.
+
+        1. Use 'CN' where N is a number from 0 to 9 that gets the Nth color
+        from the current style.
+
+        2. Single character code from the table below.
 
         +------+---------+
         | Code | Color   |
@@ -379,13 +395,10 @@ def plot_cli(
         | k    | black   |
         +------+---------+
 
-        +---------+-----------+
-        | Number  | Color     |
-        +=========+===========+
-        | 0.75    | 0.75 gray |
-        +---------+-----------+
-        | ...etc. |           |
-        +---------+-----------+
+        3. Number between 0 and 1 that represents the level of gray, where 0 is
+        white an 1 is black.
+
+        4. Any of the HTML color names.
 
         +------------------+
         | HTML Color Names |
@@ -486,7 +499,7 @@ def plot_cli(
         +-------+----------------+
         | d     | thin diamond   |
         +-------+----------------+
-        | _     | hline          |
+        | _     | hlines_y          |
         +-------+----------------+
         | None  | nothing        |
         +-------+----------------+
@@ -660,8 +673,86 @@ def plot_cli(
     {source_units}
     {target_units}
     {round_index}
+    plot_styles: str
+        [optional, default is "default"]
 
-    """
+        Set the style of the plot.  One or more of Matplotlib styles "classic",
+        "Solarize_Light2", "bmh", "dark_background", "fast", "fivethirtyeight",
+        "ggplot", "grayscale", "seaborn", "seaborn-bright",
+        "seaborn-colorblind", "seaborn-dark", "seaborn-dark-palette",
+        "seaborn-darkgrid", "seaborn-deep", "seaborn-muted",
+        "seaborn-notebook", "seaborn-paper", "seaborn-pastel",
+        "seaborn-poster", "seaborn-talk", "seaborn-ticks", "seaborn-white",
+        "seaborn-whitegrid", "tableau-colorblind10", and
+
+        SciencePlots styles "science", "grid", "ieee", "scatter", "notebook",
+        "high-vis", "bright", "vibrant", "muted", and "retro".
+
+        If multiple styles then each over rides some or all of the
+        characteristics of the previous.
+
+        Color Blind Appropriate Styles
+
+        The styles "seaborn-colorblind", "tableau-colorblind10", "bright",
+        "vibrant", and "muted" are all styles that are setup to be able to be
+        distinguished by someone with color blindness.
+
+        Black, White, and Gray Styles
+
+        The "ieee" style is appropriate for black, white, and gray, however the
+        "ieee" also will change the chart size to fit in a column of the "IEEE"
+        journal.
+
+        The "grayscale" is another style useful for photo-copyable black,
+        white, nd gray.
+
+        Matplotlib styles:
+            https://matplotlib.org/3.3.1/gallery/style_sheets/style_sheets_reference.html
+
+        SciencePlots styles:
+            https://github.com/garrettj403/SciencePlots
+
+    hlines_y:
+        [optional, defaults to None]
+
+        Number or list of y values where to place a horizontal line.
+    hlines_xmin:
+        [optional, defaults to None]
+
+        List of minimum x values to start the horizontal line.  If a list must be same length as `hlines_y`.  If a single number will be used as the minimum x values for all horizontal lines.  A missing value or None will start at the minimum x value for the entire plot.
+    hlines_xmax:
+        [optional, defaults to None]
+
+        List of maximum x values to end each horizontal line.  If a list must be same length as `hlines_y`.  If a single number will be the maximum x value for all horizontal lines.  A missing value or None will end at the maximum x value for the entire plot.
+    hlines_colors:
+        [optional, defaults to None]
+
+        List of colors for the horizontal lines.  If a single color then will be used as the color for all horizontal lines.  If a list must be same length as `hlines_y`.  If None will take from the color pallette in the current plot style.
+    hlines_linestyles:
+        [optional, defaults to None]
+
+        List of linestyles for the horizontal lines.  If a single linestyle then will be used as the linestyle for all horizontal lines.  If a list must be same length as `hlines_y`.  If None will take for the standard linestyles list.
+    vlines_x:
+        [optional, defaults to None]
+
+        List of x values where to place a vertical line.
+    vlines_ymin:
+        [optional, defaults to None]
+
+        List of minimum y values to start the vertical line.  If a list must be same length as `vlines_x`.  If a single number will be used as the minimum x values for all vertical lines.  A missing value or None will start at the minimum x value for the entire plot.
+    vlines_ymax:
+        [optional, defaults to None]
+
+        List of maximum x values to end each vertical line.  If a list must be same length as `vlines_x`.  If a single number will be the maximum x value for all vertical lines.  A missing value or None will end at the maximum x value for the entire plot.
+    vlines_colors:
+        [optional, defaults to None]
+
+        List of colors for the vertical lines.  If a single color then will be used as the color for all vertical lines.  If a list must be same length as `vlines_x`.  If None will take from the color pallette in the current plot style.
+    vlines_linestyles:
+        [optional, defaults to None]
+
+        List of linestyles for the vertical lines.  If a single linestyle then will be used as the linestyle for all vertical lines.  If a list must be same length as `vlines_x`.  If None will take for the standard linestyles list.
+        """
     plt = plot(
         input_ts=input_ts,
         columns=columns,
@@ -717,6 +808,17 @@ def plot_cli(
         source_units=source_units,
         target_units=target_units,
         lag_plot_lag=lag_plot_lag,
+        plot_styles=plot_styles,
+        hlines_y=hlines_y,
+        hlines_xmin=hlines_xmin,
+        hlines_xmax=hlines_xmax,
+        hlines_colors=hlines_colors,
+        hlines_linestyles=hlines_linestyles,
+        vlines_x=vlines_x,
+        vlines_ymin=vlines_ymin,
+        vlines_ymax=vlines_ymax,
+        vlines_colors=vlines_colors,
+        vlines_linestyles=vlines_linestyles,
     )
 
 
@@ -796,6 +898,68 @@ def plot_cli(
         1,
     ],
     prob_plot_sort_values=[str, ["domain", ["ascending", "descending"]], 1],
+    plot_styles=[
+        str,
+        [
+            "domain",
+            [
+                "classic",
+                "Solarize_Light2",
+                "bmh",
+                "dark_background",
+                "fast",
+                "fivethirtyeight",
+                "ggplot",
+                "grayscale",
+                "seaborn",
+                "seaborn-bright",
+                "seaborn-colorblind",
+                "seaborn-dark",
+                "seaborn-dark-palette",
+                "seaborn-darkgrid",
+                "seaborn-deep",
+                "seaborn-muted",
+                "seaborn-notebook",
+                "seaborn-paper",
+                "seaborn-pastel",
+                "seaborn-poster",
+                "seaborn-talk",
+                "seaborn-ticks",
+                "seaborn-white",
+                "seaborn-whitegrid",
+                "tableau-colorblind10",
+                "science",
+                "grid",
+                "ieee",
+                "scatter",
+                "notebook",
+                "high-vis",
+                "bright",
+                "vibrant",
+                "muted",
+                "retro",
+            ],
+        ],
+        None,
+    ],
+    hlines_y=[float, ["pass", []], None],
+    hlines_xmin=[float, ["pass", []], None],
+    hlines_xmax=[float, ["pass", []], None],
+    hlines_colors=[str, ["pass", []], None],
+    hlines_linestyles=[
+        str,
+        ["domain", ["auto", None, "", " ", "  "] + LINE_LIST],
+        None,
+    ],
+    vlines_x=[float, ["pass", []], None],
+    vlines_ymin=[float, ["pass", []], None],
+    vlines_ymax=[float, ["pass", []], None],
+    vlines_colors=[str, ["pass", []], None],
+    vlines_linestyles=[
+        str,
+        ["domain", ["auto", None, "", " ", "  "] + LINE_LIST],
+        None,
+    ],
 )
 def plot(
     input_ts="-",
@@ -852,6 +1016,17 @@ def plot(
     source_units=None,
     target_units=None,
     lag_plot_lag=1,
+    plot_styles="bright",
+    hlines_y=None,
+    hlines_xmin=None,
+    hlines_xmax=None,
+    hlines_colors=None,
+    hlines_linestyles="-",
+    vlines_x=None,
+    vlines_ymin=None,
+    vlines_ymax=None,
+    vlines_colors=None,
+    vlines_linestyles="-",
 ):
     r"""Plot data."""
     # Need to work around some old option defaults with the implementation of
@@ -956,7 +1131,7 @@ l1,l2,l3,...  where l1 is the legend for x1,y1, l2 is the legend for x2,y2,
         lnames = tsd.columns
 
     if colors == "auto":
-        colors = COLOR_LIST
+        colors = None
     else:
         colors = tsutils.make_list(colors)
 
@@ -1016,17 +1191,10 @@ but you have {2} time-series.
         linestyles = [" " if i in ["  ", None] else i for i in linestyles]
     markerstyles = [" " if i is None else i for i in markerstyles]
 
-    icolors = itertools.cycle(colors)
-    imarkerstyles = itertools.cycle(markerstyles)
-    ilinestyles = itertools.cycle(linestyles)
-
-    style = [
-        "{0}{1}{2}".format(next(icolors), next(imarkerstyles), next(ilinestyles))
-        for i in list(range(len(tsd.columns)))
-    ]
-
-    # reset to beginning of iterator
-    icolors = itertools.cycle(colors)
+    if colors is not None:
+        icolors = itertools.cycle(colors)
+    else:
+        icolors = None
     imarkerstyles = itertools.cycle(markerstyles)
     ilinestyles = itertools.cycle(linestyles)
 
@@ -1095,6 +1263,18 @@ The {0} setting for yaxis is ignored.
     xlim = _know_your_limits(xlim, axis=xaxis)
     ylim = _know_your_limits(ylim, axis=yaxis)
 
+    plot_styles = tsutils.make_list(plot_styles) + ["no-latex"]
+    style_loc = os.path.join(
+        os.path.dirname(__file__), os.pardir, "SciencePlots_styles"
+    )
+    plot_styles = [
+        os.path.join(style_loc, i + ".mplstyle")
+        if os.path.exists(os.path.join(style_loc, i + ".mplstyle"))
+        else i
+        for i in plot_styles
+    ]
+    plt.style.use(plot_styles)
+
     figsize = tsutils.make_list(figsize, n=2)
     _, ax = plt.subplots(figsize=figsize)
 
@@ -1157,7 +1337,6 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             subplots=subplots,
             sharex=sharex,
             sharey=sharey,
-            style=None,
             logx=logx,
             logy=logy,
             xlim=xlim,
@@ -1168,9 +1347,22 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             drawstyle=drawstyle,
         )
         for index, line in enumerate(ax.lines):
-            plt.setp(line, color=style[index][0])
-            plt.setp(line, marker=style[index][1])
-            plt.setp(line, linestyle=style[index][2:])
+            if icolors is not None:
+                c = next(icolors)
+            else:
+                c = None
+            if imarkerstyles is not None:
+                m = next(imarkerstyles)
+            else:
+                m = None
+            if ilinestyles is not None:
+                l = next(ilinestyles)
+            else:
+                l = None
+            if c is not None:
+                plt.setp(line, color=c)
+            plt.setp(line, marker=m)
+            plt.setp(line, linestyle=l)
         xtitle = xtitle or "Time"
         if legend is True:
             plt.legend(loc="best")
@@ -1221,11 +1413,16 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             oxdata = np.array(ndf.iloc[:, 0])
             oydata = np.array(ndf.iloc[:, 1])
 
+            if icolors is not None:
+                c = next(icolors)
+            else:
+                c = None
+
             plotdict[(logx, logy)](
                 oxdata,
                 oydata,
                 linestyle=next(ilinestyles),
-                color=next(icolors),
+                color=c,
                 marker=next(imarkerstyles),
                 label=lnames[colindex],
                 drawstyle=drawstyle,
@@ -1259,17 +1456,22 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             elif prob_plot_sort_values == "descending":
                 oydata = np.sort(oydata)[::-1]
             n = len(oydata)
+
             norm_axis = ax.xaxis
             oxdata = ppf(tsutils.set_plotting_position(n, plotting_position))
             if type in ["norm_yaxis", "lognorm_yaxis", "weibull_yaxis"]:
                 oxdata, oydata = oydata, oxdata
                 norm_axis = ax.yaxis
 
+            if icolors is not None:
+                c = next(icolors)
+            else:
+                c = None
             plotdict[(logx, logy)](
                 oxdata,
                 oydata,
                 linestyle=next(ilinestyles),
-                color=next(icolors),
+                color=c,
                 marker=next(imarkerstyles),
                 label=lnames[colindex],
                 drawstyle=drawstyle,
@@ -1334,9 +1536,22 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             figsize=figsize,
         )
         for index, line in enumerate(ax.lines):
-            plt.setp(line, color=style[index][0])
-            plt.setp(line, marker=style[index][1])
-            plt.setp(line, linestyle=style[index][2:])
+            if icolors is not None:
+                c = next(icolors)
+            else:
+                c = None
+            if imarkerstyles is not None:
+                m = next(imarkerstyles)
+            else:
+                m = None
+            if ilinestyles is not None:
+                l = next(ilinestyles)
+            else:
+                l = None
+            if c is not None:
+                plt.setp(line, color=c)
+            plt.setp(line, marker=m)
+            plt.setp(line, linestyle=l)
         ytitle = ytitle or "Density"
         if legend is True:
             plt.legend(loc="best")
@@ -1367,25 +1582,43 @@ as x,y pairs or an x-index and one y data column.  You supplied {0} columns.
             ax=ax1,
         )
         for index, line in enumerate(ax1.lines):
-            plt.setp(line, color=style[index][0])
-            plt.setp(line, marker=style[index][1])
-            plt.setp(line, linestyle=style[index][2:])
+            if icolors is not None:
+                c = next(icolors)
+            else:
+                c = None
+            if imarkerstyles is not None:
+                m = next(imarkerstyles)
+            else:
+                m = None
+            if ilinestyles is not None:
+                l = next(ilinestyles)
+            else:
+                l = None
+            if c is not None:
+                plt.setp(line, color=c)
+            plt.setp(line, marker=m)
+            plt.setp(line, linestyle=l)
         xtitle = xtitle or "Time"
         ylimits = ax1.get_ylim()
         ny = np.linspace(ylimits[0], ylimits[1], 1000)
 
         # reset to beginning of iterator
-        icolors = itertools.cycle(colors)
+        if icolors is not None:
+            icolors = itertools.cycle(colors)
+        else:
+            icolors = None
         imarkerstyles = itertools.cycle(markerstyles)
         ilinestyles = itertools.cycle(linestyles)
         for col in range(len(tsd.columns)):
             xvals = tsd.iloc[:, col].dropna().values
             pdf = gaussian_kde(xvals)
+            if icolors is not None:
+                c = next(icolors)
             ax0.plot(
                 pdf(ny),
                 ny,
                 linestyle=next(ilinestyles),
-                color=next(icolors),
+                color=c,
                 marker=next(imarkerstyles),
                 label=tsd.columns[col],
                 drawstyle=drawstyle,
@@ -1470,7 +1703,10 @@ The "heatmap" plot type can only work with daily time series.
         kind = "bar"
         if type[:4] == "barh":
             kind = "barh"
-        color = [next(icolors) for i in range(len(tsd.columns))]
+        if icolors is not None:
+            c = [next(icolors) for i in range(len(tsd.columns))]
+        else:
+            c = None
         tsd.plot(
             ax=ax,
             kind=kind,
@@ -1482,7 +1718,7 @@ The "heatmap" plot type can only work with daily time series.
             ylim=ylim,
             figsize=figsize,
             linestyle=None,
-            color=color,
+            color=c,
         )
 
         hatches = [next(ibar_hatchstyles) for i in range(len(tsd.columns))]
@@ -1519,7 +1755,63 @@ The "heatmap" plot type can only work with daily time series.
     elif type == "histogram":
         tsd.hist(figsize=figsize, sharey=sharey, sharex=sharex)
 
-    if xy_match_line:
+    if hlines_y is not None:
+        hlines_y = tsutils.make_list(hlines_y)
+        hlines_xmin = tsutils.make_list(hlines_xmin)
+        hlines_xmax = tsutils.make_list(hlines_xmax)
+        hlines_colors = tsutils.make_list(hlines_colors)
+        hlines_linestyles = tsutils.make_list(hlines_linestyles)
+        nxlim = ax.get_xlim()
+        if hlines_xmin is None:
+            hlines_xmin = nxlim[0]
+        if hlines_xmax is None:
+            hlines_xmax = nxlim[1]
+    if vlines_x is not None:
+        vlines_x = tsutils.make_list(vlines_x)
+        vlines_ymin = tsutils.make_list(vlines_ymin)
+        vlines_ymax = tsutils.make_list(vlines_ymax)
+        vlines_colors = tsutils.make_list(vlines_colors)
+        vlines_linestyles = tsutils.make_list(vlines_linestyles)
+        nylim = ax.get_ylim()
+        if vlines_ymin is None:
+            vlines_ymin = nylim[0]
+        if vlines_ymax is None:
+            vlines_ymax = nylim[1]
+    if type in [
+        "time",
+        "xy",
+        "bar",
+        "bar_stacked",
+        "histogram",
+        "norm_xaxis",
+        "lognorm_xaxis",
+        "weibull_xaxis",
+        "norm_yaxis",
+        "lognorm_yaxis",
+        "weibull_yaxis",
+    ]:
+        if hlines_y is not None:
+            if type in ["norm_yaxis", "lognorm_yaxis", "weibull_yaxis"]:
+                hlines_y = ppf(tsutils.make_list(hlines_y))
+            plt.hlines(
+                hlines_y,
+                hlines_xmin,
+                hlines_xmax,
+                colors=hlines_colors,
+                linestyles=hlines_linestyles,
+            )
+        if vlines_x is not None:
+            if type in ["norm_xaxis", "lognorm_xaxis", "weibull_xaxis"]:
+                vlines_x = ppf(tsutils.make_list(vlines_x))
+            plt.vlines(
+                vlines_x,
+                vlines_ymin,
+                vlines_ymax,
+                colors=vlines_colors,
+                linestyles=vlines_linestyles,
+            )
+
+    if type == "xy" and xy_match_line:
         if isinstance(xy_match_line, str):
             xymsty = xy_match_line
         else:
